==> haskell-xcb-types-0.8.0-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-xcb-types.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xcb-types
version: 0.8.0
id: xcb-types-0.8.0-2Ku92yCYNyIG7ZaknHxybk
key: xcb-types-0.8.0-2Ku92yCYNyIG7ZaknHxybk
license: BSD3
maintainer: Antoine Latter <aslatter@gmail.com>
homepage: http://community.haskell.org/~aslatter/code/xcb-types
synopsis: Parses XML files used by the XCB project
description:
    This package provides types which mirror the structures
    used in the XCB code generation XML files.
    .
    See project http://xcb.freedesktop.org/ for more information about the XCB
    project.
    .
    The XML files describe the data-types, events and requests used by the
    X Protocol, and are used to auto-generate large parts of the XCB project.
    .
    This package parses these XML files into Haskell data structures.
    .
    If you want to do something with these XML descriptions but don'\''t want
    to learn XSLT, this package should help.
    .
    This version of xcb-types is intended to fully parse the X Protocol
    description version 1.4.
category: Data
author: Antoine Latter
exposed: True
indefinite: False
exposed-modules:
    Data.XCB Data.XCB.FromXML Data.XCB.Pretty Data.XCB.Types
hidden-modules: Data.XCB.Utils
abi: 0089946c083a5d80fcc70e86a8cbe596
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/xcb-types-0.8.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/xcb-types-0.8.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/xcb-types-0.8.0
hs-libraries: HSxcb-types-0.8.0-2Ku92yCYNyIG7ZaknHxybk
depends:
    base-4.10.1.0 containers-0.5.10.2 mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
    pretty-1.1.3.3 xml-1.3.14-4CFkuDapbpFLOtwR0lZo9m
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
             pretty-1.1.3.3=229bcf5342145ac1755207fe83d29780
             xml-1.3.14-4CFkuDapbpFLOtwR0lZo9m=54ceb3ab32cca0374ff7cee0a256661e
haddock-interfaces: /usr/share/doc/haskell-xcb-types/html/xcb-types.haddock
haddock-html: /usr/share/doc/haskell-xcb-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xcb-types-0.8.0-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-xcb-types.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xcb-types
version: 0.8.0
id: xcb-types-0.8.0-EzQQ4fyUfFR477WE3O83cV
key: xcb-types-0.8.0-EzQQ4fyUfFR477WE3O83cV
license: BSD3
maintainer: Antoine Latter <aslatter@gmail.com>
homepage: http://community.haskell.org/~aslatter/code/xcb-types
synopsis: Parses XML files used by the XCB project
description:
    This package provides types which mirror the structures
    used in the XCB code generation XML files.
    .
    See project http://xcb.freedesktop.org/ for more information about the XCB
    project.
    .
    The XML files describe the data-types, events and requests used by the
    X Protocol, and are used to auto-generate large parts of the XCB project.
    .
    This package parses these XML files into Haskell data structures.
    .
    If you want to do something with these XML descriptions but don'\''t want
    to learn XSLT, this package should help.
    .
    This version of xcb-types is intended to fully parse the X Protocol
    description version 1.4.
category: Data
author: Antoine Latter
exposed: True
indefinite: False
exposed-modules:
    Data.XCB Data.XCB.FromXML Data.XCB.Pretty Data.XCB.Types
hidden-modules: Data.XCB.Utils
abi: 259db9014269ed786544db7320911a2c
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/xcb-types-0.8.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/xcb-types-0.8.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/xcb-types-0.8.0
hs-libraries: HSxcb-types-0.8.0-EzQQ4fyUfFR477WE3O83cV
depends:
    base-4.10.1.0 containers-0.5.10.2 mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
    pretty-1.1.3.3 xml-1.3.14-gmCpsUXEJ0Cd36ZPTskAU
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
             pretty-1.1.3.3=229bcf5342145ac1755207fe83d29780
             xml-1.3.14-gmCpsUXEJ0Cd36ZPTskAU=d10a974e22e128d84bfcf55c875efa2c
haddock-interfaces: /usr/share/doc/haskell-xcb-types/html/xcb-types.haddock
haddock-html: /usr/share/doc/haskell-xcb-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
